Django Apple Podcast — django-applepodcast 0.1 documentation

# Django Apple Podcast

Django Apple Podcast is a Django podcast application optimized for Apple Podcasts. Formerly Django iTunes Podcast.

- Package distribution
- Code repository
- Documentation
- Tests

An online demo also exists.

- Online demo
- Online demo code repository

## Install

    $ pip install django-applepodcast

Add to `settings.py`.

    INSTALLED_APPS = [
        # ...
        'podcast',
    ]

Add to `urls.py`.

    from django.conf.urls import url, include

    urlpatterns = [
        # ...
        url(r'^podcast/', include('podcast.urls')),
    ]

Migrate the database.

    $ python manage.py migrate

Load the fixtures.

    $ python manage.py loaddata podcast_category.json

## Usage

Run the local server.

    $ python manage.py runserver

Visit either the show view or the admin.

- http://127.0.0.1:8000/podcast/
- http://127.0.0.1:8000/admin/podcast/

## Contents

- Install
- Usage
  - Structure
  - Enclosures
  - Protocols
  - Submission
  - Badges
- Settings
  - `PODCAST_SINGULAR`
  - `PODCAST_ID`
  - `PODCAST_EPISODE_LIMIT`
  - `PODCAST_NO_ARTWORK`
  - `PODCAST_PAGINATE_BY`
  - `PODCAST_ALLOWED_TAGS`
- Feed
  - Sample
  - Sample differences
- Admin
  - App
  - Shows
  - Episodes
  - Enclosures
  - Categories
  - Speakers
- Documentation
- Tests
- Resources
  - Documentation
  - Specifications
  - Validators
  - Resources
  - Marketing
  - Submission

## Indices and tables

- Index
- Module Index
- Search Page